@@ -59,8 +59,9 @@ class LogsHandler(HttpBaseHandler):
 
         self.name = name
         self.environment = environment
+
         if process:
-            self.qp['process'] = ','.join(process)
+            self.qp['process'] = process
 
         if limit:
             self.qp['limit'] = limit
